# Treestamps

A library to set and retrieve timestamps to speed up operations
run recursively on directory trees.

Principal methods on the Treestamps class are: init(), get(), set(), dump().
A factory method is also provided for creating top path to Treestamp maps.

Documentation is to read the code for now.
